
pythreejs
=====================================

Version: |release|

**pythreejs** is a `Jupyter widgets`_ based `notebook`_ extension that allows Jupyter to leverage
the WebGL capabilities of modern browsers by creating bindings to the javascript library `three.js`_.


By being based on top of the jupyter-widgets infrastructure, it allows for eased integration
with other interactive tools for notebooks.


Quickstart
----------

To get started with pythreejs, install with pip::

    pip install pythreejs

.. TODO: Config calls


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index
   api/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/

.. _`three.js`: https://threejs.org/
